# AkramMajli

مكتبة بايثون تحتوي على دوال رياضية، أمثلة جاهزة، ورسوم بيانية باستخدام matplotlib.

## التثبيت

```bash
pip install AkramMajli==0.2.0
```

## الاستخدام

```python
import akrammajli

# استخدام الدوال
akrammajli.functions.example_function()

# عرض الأمثلة
akrammajli.examples.show_example()

# رسم بياني
akrammajli.plots.plot_example()
```
